darkhistory.utilities.get_grid — DarkHistory documentation

# darkhistory.utilities.get_grid

`darkhistory.utilities.` `get_grid`(a, b)

  Returns a 2D grid of coordinates from 2 1D arrays.

  Parameters: | a : ndarray First array. b : ndarray Second array.
  Returns: | ndarray 2D array with grid values from a and b.

  Notes

  This function returns an array that when passed to `scipy.interpolate.RegularGridInterpolator` produces the same result as `scipy.interpolate.interp2d(a, b)`.

#### Previous topic

darkhistory.utilities.exp_expn

#### Next topic

darkhistory.utilities.hyp2f1_func_real

### This Page

Show Source